@@ -27,7 +27,7 @@ class XMLTestData():
         assert n in self.data, XMLTestDataException("No data named %s in test case %s" % (n, self.name))
         return self.data[n]
 
-    def as_etree(self, n, remove_whitespace=True, remove_comments=True):
+    def as_etree(self, n, remove_whitespace=False, remove_comments=False):
         return xmlsec.parse_xml(self.as_buf(n), remove_whitespace=remove_whitespace, remove_comments=remove_comments)
 
 
@@ -39,6 +39,7 @@ def load_test_data(path=None):
         return  # fool unittest that executes this function
     cases = {}
     for case_n in pkg_resources.resource_listdir(__name__, path):
-        case = XMLTestData(__name__, os.path.join(path, case_n))
-        cases[case_n] = case
+        if case_n[0] != '.': # ignore hidden files/directories
+            case = XMLTestData(__name__, os.path.join(path, case_n))
+            cases[case_n] = case
     return cases
